%undefine _package_note_flags
# TESTING NOTE: We cannot run the tests, because they requires ppx_jane.
# We do not yet have that package in Fedora.  Even if we did, it requires this
# package to build, so we would introduce a circular dependency.

%ifnarch %{ocaml_native_compiler}
%global debug_package %{nil}
%endif

# Break a circular dependency on ocaml-odoc
%bcond_with doc

%global upname  ppx_let

Name:           ocaml-ppx-let
Version:        0.15.0
Release:        4%{?dist}
Summary:        Monadic let-bindings for OCaml

License:        MIT
URL:            https://github.com/janestreet/ppx_let
Source0:        %{url}/archive/v%{version}/%{upname}-%{version}.tar.gz

BuildRequires:  ocaml >= 4.08.0
BuildRequires:  ocaml-base-devel >= 0.15
BuildRequires:  ocaml-dune >= 2.0.0
BuildRequires:  ocaml-ppx-here-devel >= 0.15
BuildRequires:  ocaml-ppxlib-devel >= 0.23.0

%if %{with doc}
BuildRequires:  ocaml-odoc
%endif

%description
Ppx_let is a ppx rewriter for monadic and applicative let bindings,
match expressions, and if expressions.

The aim of this rewriter is to make monadic and applicative code look
nicer by writing custom binders the same way that we normally bind
variables.  In OCaml, the common way to bind the result of a computation
to a variable is:

  let VAR = EXPR in BODY

ppx_let simply adds two new binders: let%%bind and let%%map.  These are
rewritten into calls to the bind and map functions respectively.  These
functions are expected to have

  val map  : 'a t -> f:('a -> 'b)   -> 'b t
  val bind : 'a t -> f:('a -> 'b t) -> 'b t

for some type t, as one might expect.

These functions are to be provided by the user, and are generally
expected to be part of the signatures of monads and applicatives
modules.  This is the case for all monads and applicatives defined by
the Jane Street's Core suite of libraries.

%package        devel
Summary:        Development files for %{name}
Requires:       %{name}%{?_isa} = %{version}-%{release}
Requires:       ocaml-base-devel%{?_isa}
Requires:       ocaml-ppx-here-devel%{?_isa}
Requires:       ocaml-ppxlib-devel%{?_isa}

%description    devel
The %{name}-devel package contains libraries and signature
files for developing applications that use %{name}.

%prep
%autosetup -n %{upname}-%{version}

%build
dune build %{?_smp_mflags} --verbose --release
%if %{with doc}
dune build %{?_smp_mflags} @doc
%endif

%install
dune install --destdir=%{buildroot}

%if %{with doc}
# We do not want the dune markers
find _build/default/_doc/_html -name .dune-keep -delete
%endif

# We do not want the ml files
find %{buildroot}%{_libdir}/ocaml -name \*.ml -delete

# We install the documentation with the doc macro
rm -fr %{buildroot}%{_prefix}/doc

%check
dune runtest --release

%files
%doc CHANGES.md README.md
%license LICENSE.md
%dir %{_libdir}/ocaml/%{upname}/
%dir %{_libdir}/ocaml/%{upname}/expander/
%{_libdir}/ocaml/%{upname}/META
%{_libdir}/ocaml/%{upname}/ppx.exe
%{_libdir}/ocaml/%{upname}/{,*/}*.cma
%{_libdir}/ocaml/%{upname}/{,*/}*.cmi
%ifarch %{ocaml_native_compiler}
%{_libdir}/ocaml/%{upname}/{,*/}*.cmxs
%endif

%files devel
%if %{with doc}
%doc _build/default/_doc/_html/*
%endif
%{_libdir}/ocaml/%{upname}/dune-package
%{_libdir}/ocaml/%{upname}/opam
%ifarch %{ocaml_native_compiler}
%{_libdir}/ocaml/%{upname}/{,*/}*.a
%{_libdir}/ocaml/%{upname}/{,*/}*.cmx
%{_libdir}/ocaml/%{upname}/{,*/}*.cmxa
%endif
%{_libdir}/ocaml/%{upname}/{,*/}*.cmt
%{_libdir}/ocaml/%{upname}/{,*/}*.cmti
%{_libdir}/ocaml/%{upname}/{,*/}*.mli

%changelog
* Mon Feb 28 2022 Jerry James <loganjerry@gmail.com> - 0.15.0-4
- Version 0.15.0 rerelease

* Fri Feb 04 2022 Richard W.M. Jones <rjones@redhat.com> - 0.15.0-3
- OCaml 4.13.1 rebuild to remove package notes

* Thu Feb  3 2022 Jerry James <loganjerry@gmail.com> - 0.15.0-2
- Conditionally build docs to avoid circular dependency on odoc

* Thu Jan 20 2022 Fedora Release Engineering <releng@fedoraproject.org> - 0.15.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Fri Dec 31 2021 Jerry James <loganjerry@gmail.com> - 0.15.0-1
- Initial RPM
